@@ -163,6 +163,60 @@ impl Mul for i16x16 {
   }
 }
 
+impl Add<i16> for i16x16 {
+  type Output = Self;
+  #[inline]
+  #[must_use]
+  fn add(self, rhs: i16) -> Self::Output {
+    self.add(Self::splat(rhs))
+  }
+}
+
+impl Sub<i16> for i16x16 {
+  type Output = Self;
+  #[inline]
+  #[must_use]
+  fn sub(self, rhs: i16) -> Self::Output {
+    self.sub(Self::splat(rhs))
+  }
+}
+
+impl Mul<i16> for i16x16 {
+  type Output = Self;
+  #[inline]
+  #[must_use]
+  fn mul(self, rhs: i16) -> Self::Output {
+    self.mul(Self::splat(rhs))
+  }
+}
+
+impl Add<i16x16> for i16 {
+  type Output = i16x16;
+  #[inline]
+  #[must_use]
+  fn add(self, rhs: i16x16) -> Self::Output {
+    i16x16::splat(self).add(rhs)
+  }
+}
+
+impl Sub<i16x16> for i16 {
+  type Output = i16x16;
+  #[inline]
+  #[must_use]
+  fn sub(self, rhs: i16x16) -> Self::Output {
+    i16x16::splat(self).sub(rhs)
+  }
+}
+
+impl Mul<i16x16> for i16 {
+  type Output = i16x16;
+  #[inline]
+  #[must_use]
+  fn mul(self, rhs: i16x16) -> Self::Output {
+    i16x16::splat(self).mul(rhs)
+  }
+}
+
 impl BitAnd for i16x16 {
   type Output = Self;
   #[inline]
@@ -513,7 +567,10 @@ impl i16x16 {
       if #[cfg(target_feature="avx2")] {
         Self { avx2: blend_varying_i8_m256i(f.avx2, t.avx2, self.avx2) }
       } else if #[cfg(target_feature="sse4.1")] {
-        Self { sse: blend_varying_i8_m128i(f.sse, t.sse, self.sse) }
+        Self {
+          sse0: blend_varying_i8_m128i(f.sse0, t.sse0, self.sse0),
+          sse1: blend_varying_i8_m128i(f.sse1, t.sse1, self.sse1)
+        }
       } else if #[cfg(target_feature="simd128")] {
         Self {
           simd0: v128_bitselect(t.simd0, f.simd0, self.simd0),
@@ -599,4 +656,8 @@ impl i16x16 {
       }
     }
   }
+
+  pub fn to_array(self) -> [i16; 16] {
+    cast(self)
+  }
 }
