@@ -115,6 +115,60 @@ impl Mul for i16x8 {
   }
 }
 
+impl Add<i16> for i16x8 {
+  type Output = Self;
+  #[inline]
+  #[must_use]
+  fn add(self, rhs: i16) -> Self::Output {
+    self.add(Self::splat(rhs))
+  }
+}
+
+impl Sub<i16> for i16x8 {
+  type Output = Self;
+  #[inline]
+  #[must_use]
+  fn sub(self, rhs: i16) -> Self::Output {
+    self.sub(Self::splat(rhs))
+  }
+}
+
+impl Mul<i16> for i16x8 {
+  type Output = Self;
+  #[inline]
+  #[must_use]
+  fn mul(self, rhs: i16) -> Self::Output {
+    self.mul(Self::splat(rhs))
+  }
+}
+
+impl Add<i16x8> for i16 {
+  type Output = i16x8;
+  #[inline]
+  #[must_use]
+  fn add(self, rhs: i16x8) -> Self::Output {
+    i16x8::splat(self).add(rhs)
+  }
+}
+
+impl Sub<i16x8> for i16 {
+  type Output = i16x8;
+  #[inline]
+  #[must_use]
+  fn sub(self, rhs: i16x8) -> Self::Output {
+    i16x8::splat(self).sub(rhs)
+  }
+}
+
+impl Mul<i16x8> for i16 {
+  type Output = i16x8;
+  #[inline]
+  #[must_use]
+  fn mul(self, rhs: i16x8) -> Self::Output {
+    i16x8::splat(self).mul(rhs)
+  }
+}
+
 impl BitAnd for i16x8 {
   type Output = Self;
   #[inline]
@@ -402,4 +456,8 @@ impl i16x8 {
       }
     }
   }
+
+  pub fn to_array(self) -> [i16; 8] {
+    cast(self)
+  }
 }
