@@ -89,6 +89,82 @@ impl Sub for i64x4 {
   }
 }
 
+impl Mul for i64x4 {
+  type Output = Self;
+  #[inline]
+  #[must_use]
+  fn mul(self, rhs: Self) -> Self::Output {
+    pick! {
+      if #[cfg(target_feature="simd128")] {
+        Self { simd0: i64x2_mul(self.simd0, rhs.simd0), simd1: i64x2_mul(self.simd1, rhs.simd1) }
+      } else {
+        let arr1: [i64; 4] = cast(self);
+        let arr2: [i64; 4] = cast(rhs);
+        cast([
+          arr1[0].wrapping_mul(arr2[0]),
+          arr1[1].wrapping_mul(arr2[1]),
+          arr1[2].wrapping_mul(arr2[2]),
+          arr1[3].wrapping_mul(arr2[3]),
+        ])
+      }
+    }
+  }
+}
+
+impl Add<i64> for i64x4 {
+  type Output = Self;
+  #[inline]
+  #[must_use]
+  fn add(self, rhs: i64) -> Self::Output {
+    self.add(Self::splat(rhs))
+  }
+}
+
+impl Sub<i64> for i64x4 {
+  type Output = Self;
+  #[inline]
+  #[must_use]
+  fn sub(self, rhs: i64) -> Self::Output {
+    self.sub(Self::splat(rhs))
+  }
+}
+
+impl Mul<i64> for i64x4 {
+  type Output = Self;
+  #[inline]
+  #[must_use]
+  fn mul(self, rhs: i64) -> Self::Output {
+    self.mul(Self::splat(rhs))
+  }
+}
+
+impl Add<i64x4> for i64 {
+  type Output = i64x4;
+  #[inline]
+  #[must_use]
+  fn add(self, rhs: i64x4) -> Self::Output {
+    i64x4::splat(self).add(rhs)
+  }
+}
+
+impl Sub<i64x4> for i64 {
+  type Output = i64x4;
+  #[inline]
+  #[must_use]
+  fn sub(self, rhs: i64x4) -> Self::Output {
+    i64x4::splat(self).sub(rhs)
+  }
+}
+
+impl Mul<i64x4> for i64 {
+  type Output = i64x4;
+  #[inline]
+  #[must_use]
+  fn mul(self, rhs: i64x4) -> Self::Output {
+    i64x4::splat(self).mul(rhs)
+  }
+}
+
 impl BitAnd for i64x4 {
   type Output = Self;
   #[inline]
@@ -327,6 +403,10 @@ impl i64x4 {
     let arr: [i64; 4] = cast(self);
     cast([arr[0] as f64, arr[1] as f64, arr[2] as f64, arr[3] as f64])
   }
+
+  pub fn to_array(self) -> [i64; 4] {
+    cast(self)
+  }
 }
 
 impl Not for i64x4 {
